@@ -9,7 +9,7 @@ from .heap_sort import heap_sort
 from .insertion_sort import insertion_sort
 from .intro_sort import intro_sort
 from .merge_sort import merge_sort
-from .piheonhole_sort import piheonhole_sort
+from .pigeonhole_sort import pigeonhole_sort
 from .quick_sort import quick_sort
 from .radix_sort import radix_sort
 from .selection_sort import selection_sort
