@@ -1,10 +1,11 @@
-from data_sorter.algos.selection_sort import selection_sort
+from selection_sort import selection_sort
 
 
 def bucket_sort(arr):
     '''
+    **Bucket sort cannot be performed for integer value**
+
     Bucket sort, or bin sort, is a sorting algorithm that works by distributing the elements of an arr into a number of buckets.\n
-    Bucket sort cannot be performed for integer value, so we convert all integer into fraction
     ```
     bucket_sort()
       create N buckets each of which can hold a range of values
@@ -36,4 +37,4 @@ def bucket_sort(arr):
         for j in range(len(bucket[i])):
             arr[k] = bucket[i][j]
             k += 1
-    return arr
+    return arr
\ No newline at end of file
